aarondb/engine/prefetch

Values

pub fn analyze_history(
  history: List(state.QueryContext),
) -> List(String)

Analyzes the recent query history to identify the most heavily requested attributes that might benefit from predictive prefetching.

Search Document