aarondb/shared/store

Values

pub fn find_datoms(
  db_state: state.DbState,
  pattern: #(ast.Part, String, ast.Part),
) -> List(fact.Datom)

Retrieves datoms matching a pattern from the database indices. Rich Hickey alignment: “The index is an implementation detail of the fact store.”

Search Document