aarondb/shared/utils
Values
pub fn extract_json(input: String) -> String
Extract the largest balanced JSON object from a string. This is useful for parsing LLM outputs that may contain preamble or postscript noise.
pub fn extract_json(input: String) -> String
Extract the largest balanced JSON object from a string. This is useful for parsing LLM outputs that may contain preamble or postscript noise.