aarondb/vec_index/validation

Values

pub fn query_is_valid(
  query: List(Float),
  threshold: Float,
  k: Int,
) -> Bool

True when a query can be evaluated against an index.

pub fn vector_is_valid(vec: List(Float)) -> Bool

True when a vector has at least one dimension and non-zero magnitude.

Search Document